From ac37cc965a5a6ac28a3bd2ace7299ea0425e8465 Mon Sep 17 00:00:00 2001
From: Takashi Iwai <tiwai@suse.de>
Date: Wed, 24 Mar 2021 18:01:39 +0100
Subject: [PATCH v3 2/6] ALSA: core: Use READ_ONCE() / WRITE_ONCE() for power
 state change

We need proper barriers to handle the power state change of the card.
In the normal situation in suspend/resume callbacks, the lack of the
barrier is no big problem, but if it's actually referred outside the
suspend state, it can be racy.  Fix it with READ_ONCE() and
WRITE_ONCE() macros.

Signed-off-by: Takashi Iwai <tiwai@suse.de>
---
 include/sound/core.h | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/include/sound/core.h b/include/sound/core.h
index 2e24f194ef70..b915285a2b4e 100644
--- a/include/sound/core.h
+++ b/include/sound/core.h
@@ -142,12 +142,12 @@ struct snd_card {
 #ifdef CONFIG_PM
 static inline unsigned int snd_power_get_state(struct snd_card *card)
 {
-	return card->power_state;
+	return READ_ONCE(card->power_state);
 }
 
 static inline void snd_power_change_state(struct snd_card *card, unsigned int state)
 {
-	card->power_state = state;
+	WRITE_ONCE(card->power_state, state);
 	wake_up(&card->power_sleep);
 }
 
-- 
2.26.2

